@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub new {
     my $class = shift;
@@ -24,7 +24,7 @@ sub new {
     $args{an}  ||= 'My App';
     $args{ds}  ||= 'app';
 
-    my $ua_object = $args{ua_object} || _build_user_agent( $args{ua} );
+    my $ua_object = delete $args{ua_object} || _build_user_agent( $args{ua} );
     unless ( $ua_object->isa('Furl') || $ua_object->isa('LWP::UserAgent') ) {
         Carp::croak('ua_object must be of type Furl or LWP::UserAgent');
     }
@@ -40,6 +40,12 @@ sub new {
 sub send {
     my ($self, $hit_type, $args) = @_;
 
+    return $self->_request( $self->_build_request_args( $hit_type, $args ) );
+}
+
+sub _build_request_args {
+    my ($self, $hit_type, $args) = @_;
+
     my %args = (%{$self->{args}}, %$args, t => $hit_type);
     my %required = (
         pageview    => [qw(v tid cid cd an)],
@@ -59,8 +65,7 @@ sub send {
     }
     Carp::croak('for "pageview" hit types you must set either "dl" or both "dh" and "dp"')
         if $hit_type eq 'pageview' && !($args{dl} || ($args{dh} && $args{dp}));
-
-    return $self->_request(\%args);
+    return \%args;
 }
 
 sub _request {
@@ -74,12 +79,8 @@ sub _request {
 
     # Compatibility layer for LWP::UserAgent
     my $res = $ua->post( $target, $ua->isa('Furl') ? undef : (), $args );
-    if ($self->{debug}) {
-        return $res;
-    }
-    else {
-        return $self->{debug} ? $res : $res->is_success;
-    }
+
+    return $self->{debug} ? $res : $res->is_success;
 }
 
 sub _build_user_agent {
